<?php
namespace App\Admin\Renderable;


use App\Admin\Repositories\DistAdminDistributor;
use Dcat\Admin\Grid;
use Dcat\Admin\Grid\LazyRenderable;

class DistDistributorTable extends LazyRenderable
{
    public function grid(): Grid
    {
        return Grid::make(DistAdminDistributor::with(['appearance']), function (Grid $grid) {
            $grid->view('admin.grid.table');

            $grid->column('id')->width('5%');
            $grid->column('company_name', 'Company Name')->width('25%');
            $grid->column('appearance.title' ,admin_trans_field('appearance'))->width('15%');
           // $grid->column('country', 'Country');
            $grid->column('site_name');
            $grid->column('domain_type',admin_trans_label('domain'))->display(function ($domainType) {
                $title = "";
                if ($domainType == 0) {
                    $title = $this->secondary_domain;
                } else {
                    $title = $this->custom_domain;
                }
                return "<span style='color:#586cb1'>$title</span>";
            });
            $grid->actions(function (Grid\Displayers\Actions $actions) {
                $actions->disableDelete();
                $actions->disableEdit();
                $actions->disableQuickEdit();
                $actions->disableView();
                $url = $actions->row->domain_type == 0 ? $actions->row->secondary_domain : $actions->row->custom_domain;
                $url = 'http://'.$url.':'.env('DIST_SITE_PORT');
                $actions->prepend('<a href="'.$url.'" target="_blank"><i class="fa fa-paper-plane"></i> 浏览</a>');
            });

            $grid->rowSelector()->titleColumn('company_name');
            $grid->quickSearch(['company_name']);
            $grid->paginate(10);
            $grid->filter(function (Grid\Filter $filter) {
                $filter->like('company_name')->width(4);
                $filter->like('site_name')->width(4);
            });
            $grid->model()->where('enabled', 1);
        });
    }
}
